pub enum Entry<'a> {
Occupied(OccupiedEntry<'a>),
Vacant(VacantEntry<'a>),
}Expand description
A view into an occupied or vacant mapping entry.
Variants
Implementations
Sourceimpl<'a> Entry<'a>
impl<'a> Entry<'a>
Sourcepub fn or_insert(self, default: Value) -> &'a mut Value
pub fn or_insert(self, default: Value) -> &'a mut Value
Ensures a value is present and returns a mutable reference to it.
Sourcepub fn or_insert_with<F>(self, default: F) -> &'a mut Value
pub fn or_insert_with<F>(self, default: F) -> &'a mut Value
Ensures a lazily produced value is present.
Sourcepub fn and_modify<F>(self, modify: F) -> Self
pub fn and_modify<F>(self, modify: F) -> Self
Modifies an occupied entry before returning it.